@@ -35,6 +35,8 @@ gboolean     pygdk_rectangle_from_pyobject(PyObject *object,
 
 GdkAtom pygdk_atom_from_pyobject(PyObject *object);
 GdkAtom *pygdk_atom_vector_from_sequence(PyObject *sequence, gint *num);
+PyObject *pygtk_target_list_to_list(GtkTargetList *targets);
+GtkTargetList *pygtk_target_list_from_sequence(PyObject *py_targets);
 
 typedef struct {
     PyObject *func, *data;
@@ -68,4 +70,6 @@ GType pygdk_region_get_type (void) G_GNUC_CONST;
 #define PYGDK_TYPE_REGION (pygdk_region_get_type ())
 #endif /* GDK_TYPE_REGION */
 
+void pygtk_boxed_unref_shared(PyObject *boxed);
+
 #endif
